@@ -4,6 +4,8 @@
  * Copyright (C) 2010 Creytiv.com
  */
 
+#include "re_async.h"
+
 struct re;
 
 enum {
@@ -44,6 +46,7 @@ void  libre_close(void);
 int   re_main(re_signal_h *signalh);
 void  re_cancel(void);
 int   re_debug(struct re_printf *pf, void *unused);
+int   re_nfds(void);
 
 int  re_alloc(struct re **rep);
 int  re_thread_attach(struct re *re);
@@ -54,14 +57,24 @@ void re_thread_close(void);
 void re_thread_enter(void);
 void re_thread_leave(void);
 int  re_thread_check(void);
+int  re_thread_async_init(uint16_t workers);
+void re_thread_async_close(void);
+int  re_thread_async(re_async_work_h *work, re_async_h *cb, void *arg);
+int  re_thread_async_main(re_async_work_h *work, re_async_h *cb, void *arg);
+int  re_thread_async_id(intptr_t id, re_async_work_h *work, re_async_h *cb,
+		       void *arg);
+int re_thread_async_main_id(intptr_t id, re_async_work_h *work, re_async_h *cb,
+			    void *arg);
+void re_thread_async_cancel(intptr_t id);
+void re_thread_async_main_cancel(intptr_t id);
 
 void re_set_mutex(void *mutexp);
 
+struct tmrl *re_tmrl_get(void);
 
 /** Polling methods */
 enum poll_method {
 	METHOD_NULL = 0,
-	METHOD_POLL,
 	METHOD_SELECT,
 	METHOD_EPOLL,
 	METHOD_KQUEUE,
@@ -70,6 +83,7 @@ enum poll_method {
 };
 
 int              poll_method_set(enum poll_method method);
+enum poll_method poll_method_get(void);
 enum poll_method poll_method_best(void);
 const char      *poll_method_name(enum poll_method method);
 int poll_method_type(enum poll_method *method, const struct pl *name);
